@@ -13,7 +13,10 @@ from {{ app_name }}.models import ({% for model in models %}
 # =============================================================================
 @admin.register({{ model.object_name }})
 class {{ model.object_name }}Admin(BaseModelAdmin):
+    \"\"\"
+    Customize {{ model.object_name }} Admin
+    \"\"\"
     list_display = [{% for field in model.fields %}{% if field.factory.code_line %}
         '{{ field.name }}',{% endif %}{% endfor %}
     ]
-{% endfor %}"""
\ No newline at end of file
+{% endfor %}"""
